@@ -1,9 +1,9 @@
-/*	$Id: irc.h,v 1.4 2003/08/08 23:50:19 dhartmei Exp $ */
+/*	$Id: irc.h,v 1.5 2004/04/15 10:20:35 dhartmei Exp $ */
 
 #ifndef _IRC_H_
 #define _IRC_H_
 
-void	 irc_recv(const char *, unsigned, int);
+void	 irc_recv(const char *, unsigned, int, int);
 void	 irc_send_notice(int, const char *, ...);
 void	 irc_send_code(int, const char *, const char *, const char *,
 	    const char *, ...);
